==> Text-Textile2MarcdownStandalone-0.01.tar.gz: Text-Textile2MarcdownStandalone-0.01/README.md <==
[![Actions Status](https://github.com/takihito/Text-Textile2MarcdownStandalone/actions/workflows/test.yml/badge.svg)](https://github.com/takihito/Text-Textile2MarcdownStandalone/actions)
# NAME

Text::Textile2MarcdownStandalone - Standalone converter from Textile markup to Markdown

# VERSION

version 0.01

# SYNOPSIS

    use Text::Textile2MarcdownStandalone;

    # Convert a Textile file to a Markdown file
    my $converter = Text::Textile2MarcdownStandalone->new(
      input_file  => 'input.textile',
      output_file => 'output.md',
    );
    $converter->convert;

    # Get the Markdown output as a string
    my $markdown = Text::Textile2MarcdownStandalone->new(
      input_file => 'input.textile'
    )->convert;

# DESCRIPTION

Text::Textile2MarcdownStandalone provides a simple, standalone tool to convert Textile-formatted text into Markdown. It supports:

- Headings (h1–h6)
- Ordered and unordered lists with nesting
- Emphasis, strong emphasis, and strikethrough
- Code spans and code blocks
- Blockquotes
- Links and images
- Tables, including cells spanning multiple lines
- Horizontal rules and URL protection

# METHODS

- new(%options)

    Create a new converter object. Options:

        input_file  => path to the input Textile file
        output_file => path to write the output Markdown file
                        (if omitted, convert() returns the Markdown string)

- input\_file(\[$file\])

    Get or set the input file path.

- output\_file(\[$file\])

    Get or set the output file path.

- convert

    Execute the conversion. Reads the input file, converts its content to Markdown, and either writes it to the output file or returns it as a string.

# AUTHOR

Akihito Takeda <takeda.akihito@gmail.com>

# COPYRIGHT AND LICENSE

Copyright (C) 2023 Akihito Takeda

This software is free software; you may redistribute it and/or modify it under the same terms as Perl itself.

# POD ERRORS

Hey! **The above document had some coding errors, which are explained below:**

- Around line 411:

    Non-ASCII character seen before =encoding in '(h1–h6)'. Assuming UTF-8

==> Text-Textile2MarcdownStandalone-0.02.tar.gz: Text-Textile2MarcdownStandalone-0.02/README.md <==
[![Actions Status](https://github.com/takihito/Text-Textile2MarcdownStandalone/actions/workflows/test.yml/badge.svg)](https://github.com/takihito/Text-Textile2MarcdownStandalone/actions)
# NAME

Text::Textile2MarcdownStandalone - Standalone converter from Textile markup to Markdown

# VERSION

version 0.02

# SYNOPSIS

    use Text::Textile2MarcdownStandalone;

    # Convert a Textile file to a Markdown file
    my $converter = Text::Textile2MarcdownStandalone->new(
      input_file  => 'input.textile',
      output_file => 'output.md',
    );
    $converter->convert;

    # Get the Markdown output as a string
    my $markdown = Text::Textile2MarcdownStandalone->new(
      input_file => 'input.textile'
    )->convert;

# DESCRIPTION

Text::Textile2MarcdownStandalone provides a simple, standalone tool to convert Textile-formatted text into Markdown. It supports:

- - Headings (h1-h6)
- Ordered and unordered lists with nesting
- Emphasis, strong emphasis, and strikethrough
- Code spans and code blocks
- Blockquotes
- Links and images
- Tables, including cells spanning multiple lines
- Horizontal rules and URL protection

# METHODS

- new(%options)

    Create a new converter object. Options:

        input_file  => path to the input Textile file
        output_file => path to write the output Markdown file
                        (if omitted, convert() returns the Markdown string)

- input\_file(\[$file\])

    Get or set the input file path.

- output\_file(\[$file\])

    Get or set the output file path.

- convert

    Execute the conversion. Reads the input file, converts its content to Markdown, and either writes it to the output file or returns it as a string.

# AUTHOR

Akihito Takeda <takeda.akihito@gmail.com>

# COPYRIGHT AND LICENSE

Copyright (C) 2023 Akihito Takeda

This software is free software; you may redistribute it and/or modify it under the same terms as Perl itself.
